@@ -51,9 +51,9 @@
 /* Version number of package.  */
 #define VERSION "2.06"
 /* Define to the full name and version of this package. */
-#define PACKAGE_STRING "GRUB 2.06-13+deb12u1"
+#define PACKAGE_STRING "GRUB 2.06-13"
 /* Define to the version of this package. */
-#define PACKAGE_VERSION "2.06-13+deb12u1"
+#define PACKAGE_VERSION "2.06-13"
 /* Define to the full name of this package. */
 #define PACKAGE_NAME "GRUB"
 /* Define to the address where bug reports for this package should be sent. */
